@@ -1,10 +1,12 @@
 import asyncio
-import datetime
+from datetime import datetime, timezone
 import logging
 import os.path
 import time
 from typing import Tuple, List, Dict, Any, Optional, NamedTuple, Union
-from astropy.coordinates import SkyCoord
+
+from astroplan import Observer
+from astropy.coordinates import SkyCoord, EarthLocation
 import astropy.units as u
 import numpy as np
 
@@ -32,9 +34,7 @@ class InfuxConfig(NamedTuple):
 
 
 # TODO: use asyncio in driver directly
-class PilarTelescope(
-    BaseTelescope, IOffsetsAltAz, IFilters, IFocuser, ITemperatures, IPointingSeries, FitsNamespaceMixin
-):
+class PilarTelescope(BaseTelescope, IOffsetsAltAz, IFocuser, ITemperatures, IPointingSeries, FitsNamespaceMixin):
     def __init__(
         self,
         host: str,
@@ -46,11 +46,12 @@ class PilarTelescope(
         force_filter_forward: bool = True,
         pointing_path: Optional[str] = None,
         fix_telescope_time_error: bool = False,
-        has_filterwheel: bool = True,
+        has_filterwheel: bool = False,
         influx: Optional[Union[Dict[str, Any], InfuxConfig]] = None,
+        derotator_syncmode: int = 3,
         **kwargs: Any,
     ):
-        BaseTelescope.__init__(self, **kwargs, motion_status_interfaces=["ITelescope", "IFilters", "IFocuser"])
+        BaseTelescope.__init__(self, **kwargs, motion_status_interfaces=["ITelescope", "IFocuser"])
 
         # add thread func
         self.add_background_task(self._pilar_update)
@@ -67,7 +68,14 @@ class PilarTelescope(
         # pilar
         self._pilar_connect = host, port, username, password
         log.info("Connecting to Pilar at %s:%d...", host, port)
-        self._pilar = self.add_child_object(PilarDriver, host=host, port=port, username=username, password=password)
+        self._pilar = self.add_child_object(
+            PilarDriver,
+            host=host,
+            port=port,
+            username=username,
+            password=password,
+            derotator_syncmode=derotator_syncmode,
+        )
 
         # create update thread
         self._status: Dict[str, Any] = {}
@@ -280,7 +288,6 @@ class PilarTelescope(
         keys = {
             "TEL-FOCU": ("POSITION.INSTRUMENTAL.FOCUS.REALPOS", "Focus position [mm]"),
             "TEL-ROT": ("POSITION.INSTRUMENTAL.DEROTATOR[2].REALPOS", "Derotator instrumental position at end [deg]"),
-            "DEROTOFF": ("POINTING.SETUP.DEROTATOR.OFFSET", "Derotator offset [deg]"),
             "AZOFF": ("POSITION.INSTRUMENTAL.AZ.OFFSET", "Azimuth offset"),
             "ALTOFF": ("POSITION.INSTRUMENTAL.ZD.OFFSET", "Altitude offset"),
         }
@@ -306,6 +313,12 @@ class PilarTelescope(
             filter_id = status["POSITION.INSTRUMENTAL.FILTER[2].CURRPOS"]
             hdr["FILTER"] = (await self._pilar.filter_name(int(filter_id)), "Current filter")
 
+        # derotator offset
+        derotator_position = self._calculate_derotator_position(
+            hdr["TEL-RA"][0], hdr["TEL-DEC"][0], hdr["TEL-ALT"][0], Time.now()
+        )
+        hdr["DEROTOFF"] = (derotator_position - hdr["TEL-ROT"][0], "Derotator offset [deg]")
+
         # return it
         return self._filter_fits_namespace(hdr, namespaces=namespaces, **kwargs)
 
@@ -757,7 +770,7 @@ class PilarTelescope(
         await self._pilar.safe_set("POINTING.MODEL.CLEAR", 1, msg="Could not clear list of measurements: ")
 
         # set filename
-        dt = datetime.datetime.utcnow().strftime("%Y%m%d-%H%M%S")
+        dt = datetime.now(timezone.utc).strftime("%Y%m%d-%H%M%S")
         filename = os.path.join(self._pointing_path, f"pointing_{dt}.dat")
         await self._pilar.safe_set("POINTING.MODEL.FILE", filename, msg="Could not set filename: ")
 
